from pyiso20022.colr.colr_015_001_04.colr_015_001_04 import (
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmount,
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    AmountAndDirection20,
    CollateralAccount2,
    CollateralAccountIdentificationType2Choice,
    CollateralAccountType1Code,
    CreditDebitCode,
    DateAndDateTimeChoice,
    DatePeriodDetails,
    Document,
    ExposureType5Code,
    Frequency1Code,
    GenericIdentification30,
    GenericIdentification36,
    InterestCalculation4,
    InterestPaymentStatementV04,
    InterestStatement4,
    NameAndAddress6,
    Obligation4,
    Pagination,
    PartyIdentification100Choice,
    PostalAddress2,
    Statement32,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "AmountAndDirection20",
    "CollateralAccount2",
    "CollateralAccountIdentificationType2Choice",
    "CollateralAccountType1Code",
    "CreditDebitCode",
    "DateAndDateTimeChoice",
    "DatePeriodDetails",
    "Document",
    "ExposureType5Code",
    "Frequency1Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "InterestCalculation4",
    "InterestPaymentStatementV04",
    "InterestStatement4",
    "NameAndAddress6",
    "Obligation4",
    "Pagination",
    "PartyIdentification100Choice",
    "PostalAddress2",
    "Statement32",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.colr.colr_013_001_04.colr_013_001_04 import (
    ActiveCurrencyAndAmount,
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    CalculationMethod1Code,
    CollateralAccount2,
    CollateralAccountIdentificationType2Choice,
    CollateralAccountType1Code,
    CollateralBalance1,
    CollateralPurpose1Choice,
    CollateralPurpose1Code,
    DateAndDateTimeChoice,
    DatePeriodDetails,
    Document,
    ExposureType5Code,
    Frequency1Code,
    GenericIdentification30,
    GenericIdentification36,
    InterestAmount1,
    InterestComputationMethod2Code,
    InterestMethod1Code,
    InterestPaymentRequestV04,
    InterestRate1Choice,
    InterestRequestSequence1Code,
    InterestResult1,
    NameAndAddress6,
    Obligation4,
    PartyIdentification100Choice,
    PostalAddress2,
    Reference20,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    VariableInterest1Rate,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "CalculationMethod1Code",
    "CollateralAccount2",
    "CollateralAccountIdentificationType2Choice",
    "CollateralAccountType1Code",
    "CollateralBalance1",
    "CollateralPurpose1Choice",
    "CollateralPurpose1Code",
    "DateAndDateTimeChoice",
    "DatePeriodDetails",
    "Document",
    "ExposureType5Code",
    "Frequency1Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "InterestAmount1",
    "InterestComputationMethod2Code",
    "InterestMethod1Code",
    "InterestPaymentRequestV04",
    "InterestRate1Choice",
    "InterestRequestSequence1Code",
    "InterestResult1",
    "NameAndAddress6",
    "Obligation4",
    "PartyIdentification100Choice",
    "PostalAddress2",
    "Reference20",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "VariableInterest1Rate",
]



from pyiso20022.colr.colr_011_001_04.colr_011_001_04 import (
    ActiveCurrencyAndAmount,
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    CollateralAccount2,
    CollateralAccountIdentificationType2Choice,
    CollateralAccountType1Code,
    CollateralSubstitutionResponse1,
    CollateralSubstitutionResponse2,
    CollateralSubstitutionResponseV04,
    DateAndDateTimeChoice,
    Document,
    ExposureType5Code,
    GenericIdentification30,
    GenericIdentification36,
    NameAndAddress6,
    Obligation4,
    PartyIdentification100Choice,
    PostalAddress2,
    RejectionReasonV021Code,
    Status4Code,
    SubstitutionResponse1,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "CollateralAccount2",
    "CollateralAccountIdentificationType2Choice",
    "CollateralAccountType1Code",
    "CollateralSubstitutionResponse1",
    "CollateralSubstitutionResponse2",
    "CollateralSubstitutionResponseV04",
    "DateAndDateTimeChoice",
    "Document",
    "ExposureType5Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "NameAndAddress6",
    "Obligation4",
    "PartyIdentification100Choice",
    "PostalAddress2",
    "RejectionReasonV021Code",
    "Status4Code",
    "SubstitutionResponse1",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.pacs.pacs_028_001_06.pacs_028_001_06 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    AmendmentInformationDetails15,
    AmountType4Choice,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    CashAccount40,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemIdentification3Choice,
    ClearingSystemMemberIdentification2,
    Contact13,
    CreditDebitCode,
    CreditorReferenceInformation3,
    CreditorReferenceType2Choice,
    CreditorReferenceType3,
    CreditTransferMandateData1,
    DateAndDateTime2Choice,
    DateAndPlaceOfBirth1,
    DateAndType1,
    DatePeriod2,
    DateType2Choice,
    Document,
    DocumentAdjustment1,
    DocumentAmount1,
    DocumentAmountType1Choice,
    DocumentLineIdentification1,
    DocumentLineInformation2,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType1,
    DocumentType2Choice,
    EquivalentAmount2,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification23,
    FitoFipaymentStatusRequestV06,
    Frequency6Code,
    Frequency36Choice,
    FrequencyAndMoment1,
    FrequencyPeriod1,
    Garnishment4,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification3,
    GenericPersonIdentification2,
    GroupHeader109,
    LocalInstrument2Choice,
    MandateClassification1Choice,
    MandateClassification1Code,
    MandateRelatedData3Choice,
    MandateRelatedInformation16,
    MandateSetupReason1Choice,
    MandateTypeInformation2,
    NamePrefix2Code,
    OrganisationIdentification39,
    OrganisationIdentificationSchemeName1Choice,
    OriginalGroupInformation27,
    OriginalGroupInformation29,
    OriginalTransactionReference42,
    OtherContact1,
    Party50Choice,
    Party52Choice,
    PartyIdentification272,
    PaymentMethod4Code,
    PaymentTransaction158,
    PaymentTypeInformation27,
    PersonIdentification18,
    PersonIdentificationSchemeName1Choice,
    PostalAddress27,
    PreferredContactMethod2Code,
    Priority2Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    Purpose2Choice,
    ReferredDocumentInformation8,
    RemittanceAmount4,
    RemittanceInformation22,
    SequenceType3Code,
    ServiceLevel8Choice,
    SettlementInstruction15,
    SettlementMethod1Code,
    StructuredRemittanceInformation18,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount3,
    TaxAuthorisation1,
    TaxData1,
    TaxParty1,
    TaxParty2,
    TaxPeriod3,
    TaxRecord3,
    TaxRecordDetails3,
    TaxRecordPeriod1Code,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "AmendmentInformationDetails15",
    "AmountType4Choice",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "CashAccount40",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemIdentification3Choice",
    "ClearingSystemMemberIdentification2",
    "Contact13",
    "CreditDebitCode",
    "CreditTransferMandateData1",
    "CreditorReferenceInformation3",
    "CreditorReferenceType2Choice",
    "CreditorReferenceType3",
    "DateAndDateTime2Choice",
    "DateAndPlaceOfBirth1",
    "DateAndType1",
    "DatePeriod2",
    "DateType2Choice",
    "Document",
    "DocumentAdjustment1",
    "DocumentAmount1",
    "DocumentAmountType1Choice",
    "DocumentLineIdentification1",
    "DocumentLineInformation2",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType1",
    "DocumentType2Choice",
    "EquivalentAmount2",
    "FitoFipaymentStatusRequestV06",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification23",
    "Frequency36Choice",
    "Frequency6Code",
    "FrequencyAndMoment1",
    "FrequencyPeriod1",
    "Garnishment4",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification3",
    "GenericPersonIdentification2",
    "GroupHeader109",
    "LocalInstrument2Choice",
    "MandateClassification1Choice",
    "MandateClassification1Code",
    "MandateRelatedData3Choice",
    "MandateRelatedInformation16",
    "MandateSetupReason1Choice",
    "MandateTypeInformation2",
    "NamePrefix2Code",
    "OrganisationIdentification39",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalGroupInformation27",
    "OriginalGroupInformation29",
    "OriginalTransactionReference42",
    "OtherContact1",
    "Party50Choice",
    "Party52Choice",
    "PartyIdentification272",
    "PaymentMethod4Code",
    "PaymentTransaction158",
    "PaymentTypeInformation27",
    "PersonIdentification18",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress27",
    "PreferredContactMethod2Code",
    "Priority2Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "Purpose2Choice",
    "ReferredDocumentInformation8",
    "RemittanceAmount4",
    "RemittanceInformation22",
    "SequenceType3Code",
    "ServiceLevel8Choice",
    "SettlementInstruction15",
    "SettlementMethod1Code",
    "StructuredRemittanceInformation18",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount3",
    "TaxAuthorisation1",
    "TaxData1",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod3",
    "TaxRecord3",
    "TaxRecordDetails3",
    "TaxRecordPeriod1Code",
]



from pyiso20022.colr.colr_013_001_05.colr_013_001_05 import (
    ActiveCurrencyAndAmount,
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    BlockChainAddressWallet5,
    CalculationMethod1Code,
    CollateralAccount3,
    CollateralAccountIdentificationType3Choice,
    CollateralAccountType1Code,
    CollateralBalance1,
    CollateralPurpose1Choice,
    CollateralPurpose1Code,
    DateAndDateTime2Choice,
    DatePeriod2,
    Document,
    ExposureType11Code,
    Frequency1Code,
    GenericIdentification30,
    GenericIdentification36,
    InterestAmount4,
    InterestComputationMethod2Code,
    InterestMethod1Code,
    InterestPaymentRequestV05,
    InterestRate1Choice,
    InterestRequestSequence1Code,
    InterestResult1,
    NameAndAddress6,
    Obligation9,
    PartyIdentification178Choice,
    PostalAddress2,
    Reference20,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    VariableInterest1Rate,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "BlockChainAddressWallet5",
    "CalculationMethod1Code",
    "CollateralAccount3",
    "CollateralAccountIdentificationType3Choice",
    "CollateralAccountType1Code",
    "CollateralBalance1",
    "CollateralPurpose1Choice",
    "CollateralPurpose1Code",
    "DateAndDateTime2Choice",
    "DatePeriod2",
    "Document",
    "ExposureType11Code",
    "Frequency1Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "InterestAmount4",
    "InterestComputationMethod2Code",
    "InterestMethod1Code",
    "InterestPaymentRequestV05",
    "InterestRate1Choice",
    "InterestRequestSequence1Code",
    "InterestResult1",
    "NameAndAddress6",
    "Obligation9",
    "PartyIdentification178Choice",
    "PostalAddress2",
    "Reference20",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "VariableInterest1Rate",
]



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05"


@dataclass(kw_only=True)
class ActiveCurrencyAndAmount:
    value: Decimal = field(
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        }
    )
    ccy: str = field(
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )


class AgreementFramework1Code(Enum):
    FBAA = "FBAA"
    BBAA = "BBAA"
    DERV = "DERV"
    ISDA = "ISDA"
    NONR = "NONR"


class CalculationMethod1Code(Enum):
    SIMP = "SIMP"
    COMP = "COMP"


class CollateralAccountType1Code(Enum):
    HOUS = "HOUS"
    CLIE = "CLIE"
    LIPR = "LIPR"
    MGIN = "MGIN"
    DFLT = "DFLT"


class CollateralPurpose1Code(Enum):
    VAMA = "VAMA"
    SINA = "SINA"


@dataclass(kw_only=True)
class DateAndDateTime2Choice:
    dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "Dt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "DtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class DatePeriod2:
    fr_dt: XmlDate = field(
        metadata={
            "name": "FrDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    to_dt: XmlDate = field(
        metadata={
            "name": "ToDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


class ExposureType11Code(Enum):
    BFWD = "BFWD"
    PAYM = "PAYM"
    CBCO = "CBCO"
    COMM = "COMM"
    CRDS = "CRDS"
    CRTL = "CRTL"
    CRSP = "CRSP"
    CCIR = "CCIR"
    CRPR = "CRPR"
    EQPT = "EQPT"
    EQUS = "EQUS"
    EXTD = "EXTD"
    EXPT = "EXPT"
    FIXI = "FIXI"
    FORX = "FORX"
    FORW = "FORW"
    FUTR = "FUTR"
    OPTN = "OPTN"
    LIQU = "LIQU"
    OTCD = "OTCD"
    RVPO = "RVPO"
    SLOA = "SLOA"
    SBSC = "SBSC"
    SCRP = "SCRP"
    SLEB = "SLEB"
    SCIR = "SCIR"
    SCIE = "SCIE"
    SWPT = "SWPT"
    TBAS = "TBAS"
    TRCP = "TRCP"
    UDMS = "UDMS"
    CCPC = "CCPC"
    EQUI = "EQUI"
    TRBD = "TRBD"
    REPO = "REPO"
    SHSL = "SHSL"


class Frequency1Code(Enum):
    YEAR = "YEAR"
    MNTH = "MNTH"
    QURT = "QURT"
    MIAN = "MIAN"
    WEEK = "WEEK"
    DAIL = "DAIL"
    ADHO = "ADHO"
    INDA = "INDA"


@dataclass(kw_only=True)
class GenericIdentification30:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification36:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 35,
        },
    )


class InterestComputationMethod2Code(Enum):
    A001 = "A001"
    A002 = "A002"
    A003 = "A003"
    A004 = "A004"
    A005 = "A005"
    A006 = "A006"
    A007 = "A007"
    A008 = "A008"
    A009 = "A009"
    A010 = "A010"
    A011 = "A011"
    A012 = "A012"
    A013 = "A013"
    A014 = "A014"
    NARR = "NARR"


class InterestMethod1Code(Enum):
    PHYS = "PHYS"
    ROLL = "ROLL"


class InterestRequestSequence1Code(Enum):
    INIT = "INIT"
    UPDA = "UPDA"


@dataclass(kw_only=True)
class PostalAddress2:
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd_id: str = field(
        metadata={
            "name": "PstCdId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        }
    )
    twn_nm: str = field(
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class Reference20:
    intrst_pmt_req_id: str = field(
        metadata={
            "name": "IntrstPmtReqId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    intrst_pmt_rspn_id: None | str = field(
        default=None,
        metadata={
            "name": "IntrstPmtRspnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class SupplementaryDataEnvelope1:
    any_element: None | object = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass(kw_only=True)
class VariableInterest1Rate:
    indx: str = field(
        metadata={
            "name": "Indx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    bsis_pt_sprd: None | Decimal = field(
        default=None,
        metadata={
            "name": "BsisPtSprd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "total_digits": 18,
            "fraction_digits": 0,
        },
    )


@dataclass(kw_only=True)
class AgreementFramework1Choice:
    agrmt_frmwk: None | AgreementFramework1Code = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    prtry_id: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class CollateralAccountIdentificationType3Choice:
    tp: None | CollateralAccountType1Code = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    prtry: None | GenericIdentification36 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class CollateralBalance1:
    held_by_pty_a: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "HeldByPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    held_by_pty_b: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "HeldByPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class CollateralPurpose1Choice:
    cd: None | CollateralPurpose1Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    prtry: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class InterestRate1Choice:
    fxd_intrst_rate: None | Decimal = field(
        default=None,
        metadata={
            "name": "FxdIntrstRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "total_digits": 11,
            "fraction_digits": 10,
        },
    )
    varbl_intrst_rate: None | VariableInterest1Rate = field(
        default=None,
        metadata={
            "name": "VarblIntrstRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress6:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        }
    )
    adr: PostalAddress2 = field(
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class SupplementaryData1:
    plc_and_nm: None | str = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: SupplementaryDataEnvelope1 = field(
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class Agreement4:
    agrmt_dtls: str = field(
        metadata={
            "name": "AgrmtDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 140,
        }
    )
    agrmt_id: None | str = field(
        default=None,
        metadata={
            "name": "AgrmtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 140,
        },
    )
    agrmt_dt: XmlDate = field(
        metadata={
            "name": "AgrmtDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    base_ccy: str = field(
        metadata={
            "name": "BaseCcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )
    agrmt_frmwk: None | AgreementFramework1Choice = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class BlockChainAddressWallet5:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 140,
        }
    )
    tp: None | CollateralAccountIdentificationType3Choice = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class CollateralAccount3:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tp: None | CollateralAccountIdentificationType3Choice = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class InterestAmount4:
    intrst_req_seq: InterestRequestSequence1Code = field(
        metadata={
            "name": "IntrstReqSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    intrst_prd: DatePeriod2 = field(
        metadata={
            "name": "IntrstPrd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    acrd_intrst_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "AcrdIntrstAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    val_dt: XmlDate = field(
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    intrst_mtd: InterestMethod1Code = field(
        metadata={
            "name": "IntrstMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    intrst_rate: None | InterestRate1Choice = field(
        default=None,
        metadata={
            "name": "IntrstRate",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    day_cnt_bsis: None | InterestComputationMethod2Code = field(
        default=None,
        metadata={
            "name": "DayCntBsis",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    apld_whldg_tax: None | bool = field(
        default=None,
        metadata={
            "name": "ApldWhldgTax",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    clctn_mtd: None | CalculationMethod1Code = field(
        default=None,
        metadata={
            "name": "ClctnMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    clctn_frqcy: None | Frequency1Code = field(
        default=None,
        metadata={
            "name": "ClctnFrqcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    coll_purp: CollateralPurpose1Choice = field(
        metadata={
            "name": "CollPurp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    opng_coll_bal: None | CollateralBalance1 = field(
        default=None,
        metadata={
            "name": "OpngCollBal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    clsg_coll_bal: CollateralBalance1 = field(
        metadata={
            "name": "ClsgCollBal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    std_sttlm_instrs: None | str = field(
        default=None,
        metadata={
            "name": "StdSttlmInstrs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 140,
        },
    )
    addtl_inf: None | str = field(
        default=None,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "min_length": 1,
            "max_length": 210,
        },
    )
    ref_dtls: None | Reference20 = field(
        default=None,
        metadata={
            "name": "RefDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class InterestResult1:
    intrst_due_to_a: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "IntrstDueToA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    intrst_due_to_b: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "IntrstDueToB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    val_dt: XmlDate = field(
        metadata={
            "name": "ValDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    intrst_mtd: InterestMethod1Code = field(
        metadata={
            "name": "IntrstMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    opng_coll_bal: None | CollateralBalance1 = field(
        default=None,
        metadata={
            "name": "OpngCollBal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    clsg_coll_bal: CollateralBalance1 = field(
        metadata={
            "name": "ClsgCollBal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class PartyIdentification178Choice:
    any_bic: None | str = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification36 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    nm_and_adr: None | NameAndAddress6 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class Obligation9:
    pty_a: PartyIdentification178Choice = field(
        metadata={
            "name": "PtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    svcg_pty_a: None | PartyIdentification178Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    pty_b: PartyIdentification178Choice = field(
        metadata={
            "name": "PtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    svcg_pty_b: None | PartyIdentification178Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    coll_acct_id: None | CollateralAccount3 = field(
        default=None,
        metadata={
            "name": "CollAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    blck_chain_adr_or_wllt: None | BlockChainAddressWallet5 = field(
        default=None,
        metadata={
            "name": "BlckChainAdrOrWllt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    xpsr_tp: None | ExposureType11Code = field(
        default=None,
        metadata={
            "name": "XpsrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    valtn_dt: DateAndDateTime2Choice = field(
        metadata={
            "name": "ValtnDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class InterestPaymentRequestV05:
    tx_id: str = field(
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    oblgtn: Obligation9 = field(
        metadata={
            "name": "Oblgtn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    agrmt: Agreement4 = field(
        metadata={
            "name": "Agrmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
            "required": True,
        }
    )
    intrst_due_to_a: None | InterestAmount4 = field(
        default=None,
        metadata={
            "name": "IntrstDueToA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    intrst_due_to_b: None | InterestAmount4 = field(
        default=None,
        metadata={
            "name": "IntrstDueToB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    net_amt_dtls: None | InterestResult1 = field(
        default=None,
        metadata={
            "name": "NetAmtDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )
    splmtry_data: list[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05",
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:colr.013.001.05"

    intrst_pmt_req: InterestPaymentRequestV05 = field(
        metadata={
            "name": "IntrstPmtReq",
            "type": "Element",
            "required": True,
        }
    )



from pyiso20022.colr.colr_009_001_03.colr_009_001_03 import (
    ActiveCurrencyAndAmount,
    CollateralAccount1,
    CollateralAccountIdentificationType1Choice,
    CollateralAccountType1Code,
    DateAndDateTimeChoice,
    Dispute1,
    DisputeNotification1,
    DisputeNotification1Choice,
    DisputeResolutionType1Choice,
    DisputeResolutionType1Code,
    DisputeResolutionType2Choice,
    DisputeResolutionType2Code,
    Document,
    ExposureType5Code,
    GenericIdentification29,
    GenericIdentification30,
    MarginCallDisputeNotificationV03,
    NameAndAddress6,
    Obligation3,
    PartyIdentification33Choice,
    PostalAddress2,
    SegregatedIndependentAmountDispute1,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    VariationMarginDispute1,
)

__all__ = [
    "ActiveCurrencyAndAmount",
    "CollateralAccount1",
    "CollateralAccountIdentificationType1Choice",
    "CollateralAccountType1Code",
    "DateAndDateTimeChoice",
    "Dispute1",
    "DisputeNotification1",
    "DisputeNotification1Choice",
    "DisputeResolutionType1Choice",
    "DisputeResolutionType1Code",
    "DisputeResolutionType2Choice",
    "DisputeResolutionType2Code",
    "Document",
    "ExposureType5Code",
    "GenericIdentification29",
    "GenericIdentification30",
    "MarginCallDisputeNotificationV03",
    "NameAndAddress6",
    "Obligation3",
    "PartyIdentification33Choice",
    "PostalAddress2",
    "SegregatedIndependentAmountDispute1",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "VariationMarginDispute1",
]



from pyiso20022.colr.colr_012_001_04.colr_012_001_04 import (
    Agreement4,
    AgreementFramework1Choice,
    AgreementFramework1Code,
    CollateralAccount2,
    CollateralAccountIdentificationType2Choice,
    CollateralAccountType1Code,
    CollateralConfirmation1,
    CollateralSubstitutionConfirmation1Code,
    CollateralSubstitutionConfirmationV04,
    DateAndDateTimeChoice,
    Document,
    ExposureType5Code,
    GenericIdentification30,
    GenericIdentification36,
    NameAndAddress6,
    Obligation4,
    PartyIdentification100Choice,
    PostalAddress2,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "Agreement4",
    "AgreementFramework1Choice",
    "AgreementFramework1Code",
    "CollateralAccount2",
    "CollateralAccountIdentificationType2Choice",
    "CollateralAccountType1Code",
    "CollateralConfirmation1",
    "CollateralSubstitutionConfirmation1Code",
    "CollateralSubstitutionConfirmationV04",
    "DateAndDateTimeChoice",
    "Document",
    "ExposureType5Code",
    "GenericIdentification30",
    "GenericIdentification36",
    "NameAndAddress6",
    "Obligation4",
    "PartyIdentification100Choice",
    "PostalAddress2",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime, XmlTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01"


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


class CashAccountType4Code(Enum):
    CASH = "CASH"
    CHAR = "CHAR"
    COMM = "COMM"
    TAXE = "TAXE"
    CISH = "CISH"
    TRAS = "TRAS"
    SACC = "SACC"
    CACC = "CACC"
    SVGS = "SVGS"
    ONDP = "ONDP"
    MGLD = "MGLD"
    NREX = "NREX"
    MOMA = "MOMA"
    LOAN = "LOAN"
    SLRY = "SLRY"
    ODFT = "ODFT"


class CashClearingSystem3Code(Enum):
    ABE = "ABE"
    ART = "ART"
    AVP = "AVP"
    AZM = "AZM"
    BAP = "BAP"
    BEL = "BEL"
    BOF = "BOF"
    BRL = "BRL"
    CAD = "CAD"
    CAM = "CAM"
    CBJ = "CBJ"
    CHP = "CHP"
    DKC = "DKC"
    RTP = "RTP"
    EBA = "EBA"
    ELS = "ELS"
    ERP = "ERP"
    XCT = "XCT"
    HRK = "HRK"
    HRM = "HRM"
    HUF = "HUF"
    LGS = "LGS"
    LVL = "LVL"
    MUP = "MUP"
    NOC = "NOC"
    PCH = "PCH"
    PDS = "PDS"
    PEG = "PEG"
    PNS = "PNS"
    PVE = "PVE"
    SEC = "SEC"
    SIT = "SIT"
    SLB = "SLB"
    SPG = "SPG"
    SSK = "SSK"
    TBF = "TBF"
    TGT = "TGT"
    TOP = "TOP"
    FDW = "FDW"
    BOJ = "BOJ"
    FEY = "FEY"
    ZEN = "ZEN"
    DDK = "DDK"
    AIP = "AIP"
    BCC = "BCC"
    BDS = "BDS"
    BGN = "BGN"
    BHS = "BHS"
    BIS = "BIS"
    BSP = "BSP"
    EPM = "EPM"
    EPN = "EPN"
    FDA = "FDA"
    GIS = "GIS"
    INC = "INC"
    JOD = "JOD"
    KPS = "KPS"
    LKB = "LKB"
    MEP = "MEP"
    MRS = "MRS"
    NAM = "NAM"
    PTR = "PTR"
    ROL = "ROL"
    ROS = "ROS"
    SCP = "SCP"
    STG = "STG"
    THB = "THB"
    TIS = "TIS"
    TTD = "TTD"
    UIS = "UIS"
    MOS = "MOS"
    ZET = "ZET"
    ZIS = "ZIS"
    CHI = "CHI"
    COP = "COP"


class ClearingChannel2Code(Enum):
    RTGS = "RTGS"
    RTNS = "RTNS"
    MPNS = "MPNS"
    BOOK = "BOOK"


@dataclass(kw_only=True)
class ClearingSystemMemberIdentification3Choice:
    id: None | str = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class CurrencyAndAmount:
    value: Decimal = field(
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        }
    )
    ccy: str = field(
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )


@dataclass(kw_only=True)
class GenericIdentification3:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: None | str = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


class Instruction4Code(Enum):
    PHOA = "PHOA"
    TELA = "TELA"


class Instruction5Code(Enum):
    PHOB = "PHOB"
    TELB = "TELB"


@dataclass(kw_only=True)
class PaymentIdentification2:
    instr_id: None | str = field(
        default=None,
        metadata={
            "name": "InstrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    end_to_end_id: str = field(
        metadata={
            "name": "EndToEndId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tx_id: str = field(
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )


class Priority2Code(Enum):
    HIGH = "HIGH"
    NORM = "NORM"


@dataclass(kw_only=True)
class RemittanceInformation2:
    ustrd: list[str] = field(
        default_factory=list,
        metadata={
            "name": "Ustrd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 140,
        },
    )


@dataclass(kw_only=True)
class RestrictedProprietaryChoice:
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class SettlementDateTimeIndication1:
    dbt_dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "DbtDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    cdt_dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "CdtDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


class SettlementMethod1Code(Enum):
    INDA = "INDA"
    INGA = "INGA"
    COVE = "COVE"
    CLRG = "CLRG"


@dataclass(kw_only=True)
class SettlementTimeRequest1:
    clstm: XmlTime = field(
        metadata={
            "name": "CLSTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class SimpleIdentificationInformation2:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 34,
        }
    )


@dataclass(kw_only=True)
class AccountIdentification3Choice:
    iban: None | str = field(
        default=None,
        metadata={
            "name": "IBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[a-zA-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}",
        },
    )
    bban: None | str = field(
        default=None,
        metadata={
            "name": "BBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[a-zA-Z0-9]{1,30}",
        },
    )
    upic: None | str = field(
        default=None,
        metadata={
            "name": "UPIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[0-9]{8,17}",
        },
    )
    prtry_acct: None | SimpleIdentificationInformation2 = field(
        default=None,
        metadata={
            "name": "PrtryAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class CashAccountType2:
    cd: None | CashAccountType4Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class ClearingSystemIdentification1Choice:
    clr_sys_id: None | CashClearingSystem3Code = field(
        default=None,
        metadata={
            "name": "ClrSysId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    prtry: None | str = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class InstructionForCreditorAgent2:
    cd: None | Instruction5Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instr_inf: None | str = field(
        default=None,
        metadata={
            "name": "InstrInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 140,
        },
    )


@dataclass(kw_only=True)
class InstructionForNextAgent1:
    cd: None | Instruction4Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instr_inf: None | str = field(
        default=None,
        metadata={
            "name": "InstrInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 140,
        },
    )


@dataclass(kw_only=True)
class PaymentTypeInformation5:
    instr_prty: None | Priority2Code = field(
        default=None,
        metadata={
            "name": "InstrPrty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    svc_lvl: None | RestrictedProprietaryChoice = field(
        default=None,
        metadata={
            "name": "SvcLvl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    clr_chanl: None | ClearingChannel2Code = field(
        default=None,
        metadata={
            "name": "ClrChanl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    lcl_instrm: None | RestrictedProprietaryChoice = field(
        default=None,
        metadata={
            "name": "LclInstrm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class PostalAddress1:
    adr_tp: None | AddressType2Code = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    adr_line: list[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "max_occurs": 5,
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 70,
        },
    )
    bldg_nb: None | str = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_cd: None | str = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: None | str = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class BranchData:
    id: None | str = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    pstl_adr: None | PostalAddress1 = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class CashAccount7:
    id: AccountIdentification3Choice = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    tp: None | CashAccountType2 = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    ccy: None | str = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[A-Z]{3,3}",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class FinancialInstitutionIdentification3:
    bic: None | str = field(
        default=None,
        metadata={
            "name": "BIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    clr_sys_mmb_id: None | ClearingSystemMemberIdentification3Choice = field(
        default=None,
        metadata={
            "name": "ClrSysMmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pstl_adr: None | PostalAddress1 = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    prtry_id: None | GenericIdentification3 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress7:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        }
    )
    pstl_adr: PostalAddress1 = field(
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class FinancialInstitutionIdentification5Choice:
    bic: None | str = field(
        default=None,
        metadata={
            "name": "BIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    clr_sys_mmb_id: None | ClearingSystemMemberIdentification3Choice = field(
        default=None,
        metadata={
            "name": "ClrSysMmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    nm_and_adr: None | NameAndAddress7 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    prtry_id: None | GenericIdentification3 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    cmbnd_id: None | FinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "CmbndId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class BranchAndFinancialInstitutionIdentification3:
    fin_instn_id: FinancialInstitutionIdentification5Choice = field(
        metadata={
            "name": "FinInstnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    brnch_id: None | BranchData = field(
        default=None,
        metadata={
            "name": "BrnchId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class CreditTransferTransactionInformation3:
    pmt_id: PaymentIdentification2 = field(
        metadata={
            "name": "PmtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    pmt_tp_inf: None | PaymentTypeInformation5 = field(
        default=None,
        metadata={
            "name": "PmtTpInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intr_bk_sttlm_amt: CurrencyAndAmount = field(
        metadata={
            "name": "IntrBkSttlmAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    intr_bk_sttlm_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "IntrBkSttlmDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    sttlm_tm_indctn: None | SettlementDateTimeIndication1 = field(
        default=None,
        metadata={
            "name": "SttlmTmIndctn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    sttlm_tm_req: None | SettlementTimeRequest1 = field(
        default=None,
        metadata={
            "name": "SttlmTmReq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    prvs_instg_agt: None | BranchAndFinancialInstitutionIdentification3 = (
        field(
            default=None,
            metadata={
                "name": "PrvsInstgAgt",
                "type": "Element",
                "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            },
        )
    )
    prvs_instg_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "PrvsInstgAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instg_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "InstgAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instd_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "InstdAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt1: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt1",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt1_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt1Acct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt2: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt2",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt2_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt2Acct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt3: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt3",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intrmy_agt3_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "IntrmyAgt3Acct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    ultmt_dbtr: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "UltmtDbtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    dbtr: BranchAndFinancialInstitutionIdentification3 = field(
        metadata={
            "name": "Dbtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    dbtr_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "DbtrAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    dbtr_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "DbtrAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    dbtr_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "DbtrAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    cdtr_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "CdtrAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    cdtr_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "CdtrAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    cdtr: BranchAndFinancialInstitutionIdentification3 = field(
        metadata={
            "name": "Cdtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    cdtr_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "CdtrAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    ultmt_cdtr: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "UltmtCdtr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instr_for_cdtr_agt: list[InstructionForCreditorAgent2] = field(
        default_factory=list,
        metadata={
            "name": "InstrForCdtrAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instr_for_nxt_agt: list[InstructionForNextAgent1] = field(
        default_factory=list,
        metadata={
            "name": "InstrForNxtAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    rmt_inf: None | RemittanceInformation2 = field(
        default=None,
        metadata={
            "name": "RmtInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class SettlementInformation1:
    sttlm_mtd: SettlementMethod1Code = field(
        metadata={
            "name": "SttlmMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    sttlm_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "SttlmAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    clr_sys: None | ClearingSystemIdentification1Choice = field(
        default=None,
        metadata={
            "name": "ClrSys",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instg_rmbrsmnt_agt: None | BranchAndFinancialInstitutionIdentification3 = (
        field(
            default=None,
            metadata={
                "name": "InstgRmbrsmntAgt",
                "type": "Element",
                "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            },
        )
    )
    instg_rmbrsmnt_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "InstgRmbrsmntAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instd_rmbrsmnt_agt: None | BranchAndFinancialInstitutionIdentification3 = (
        field(
            default=None,
            metadata={
                "name": "InstdRmbrsmntAgt",
                "type": "Element",
                "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            },
        )
    )
    instd_rmbrsmnt_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "InstdRmbrsmntAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    thrd_rmbrsmnt_agt: None | BranchAndFinancialInstitutionIdentification3 = (
        field(
            default=None,
            metadata={
                "name": "ThrdRmbrsmntAgt",
                "type": "Element",
                "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            },
        )
    )
    thrd_rmbrsmnt_agt_acct: None | CashAccount7 = field(
        default=None,
        metadata={
            "name": "ThrdRmbrsmntAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class GroupHeader4:
    msg_id: str = field(
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    cre_dt_tm: XmlDateTime = field(
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    btch_bookg: None | bool = field(
        default=None,
        metadata={
            "name": "BtchBookg",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    nb_of_txs: str = field(
        metadata={
            "name": "NbOfTxs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
            "pattern": r"[0-9]{1,15}",
        }
    )
    ctrl_sum: None | Decimal = field(
        default=None,
        metadata={
            "name": "CtrlSum",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "total_digits": 18,
            "fraction_digits": 17,
        },
    )
    ttl_intr_bk_sttlm_amt: None | CurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "TtlIntrBkSttlmAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    intr_bk_sttlm_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "IntrBkSttlmDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    sttlm_inf: SettlementInformation1 = field(
        metadata={
            "name": "SttlmInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    pmt_tp_inf: None | PaymentTypeInformation5 = field(
        default=None,
        metadata={
            "name": "PmtTpInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instg_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "InstgAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )
    instd_agt: None | BranchAndFinancialInstitutionIdentification3 = field(
        default=None,
        metadata={
            "name": "InstdAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
        },
    )


@dataclass(kw_only=True)
class Pacs00900101:
    class Meta:
        name = "pacs.009.001.01"

    grp_hdr: GroupHeader4 = field(
        metadata={
            "name": "GrpHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "required": True,
        }
    )
    cdt_trf_tx_inf: list[CreditTransferTransactionInformation3] = field(
        default_factory=list,
        metadata={
            "name": "CdtTrfTxInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01",
            "min_occurs": 1,
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:pacs.009.001.01"

    pacs_009_001_01: Pacs00900101 = field(
        metadata={
            "name": "pacs.009.001.01",
            "type": "Element",
            "required": True,
        }
    )



from __future__ import annotations

from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03"


@dataclass(kw_only=True)
class ActiveCurrencyAndAmount:
    value: Decimal = field(
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        }
    )
    ccy: str = field(
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )


class AgreementFramework1Code(Enum):
    FBAA = "FBAA"
    BBAA = "BBAA"
    DERV = "DERV"
    ISDA = "ISDA"
    NONR = "NONR"


class CollateralAccountType1Code(Enum):
    HOUS = "HOUS"
    CLIE = "CLIE"
    LIPR = "LIPR"
    MGIN = "MGIN"
    DFLT = "DFLT"


@dataclass(kw_only=True)
class DateAndDateTimeChoice:
    dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "Dt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "DtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


class ExposureConventionType1Code(Enum):
    GROS = "GROS"
    NET1 = "NET1"


class ExposureType5Code(Enum):
    BFWD = "BFWD"
    PAYM = "PAYM"
    CCPC = "CCPC"
    COMM = "COMM"
    CRDS = "CRDS"
    CRTL = "CRTL"
    CRSP = "CRSP"
    CCIR = "CCIR"
    CRPR = "CRPR"
    EQUI = "EQUI"
    EQPT = "EQPT"
    EQUS = "EQUS"
    EXTD = "EXTD"
    EXPT = "EXPT"
    FIXI = "FIXI"
    FORX = "FORX"
    FORW = "FORW"
    FUTR = "FUTR"
    OPTN = "OPTN"
    LIQU = "LIQU"
    OTCD = "OTCD"
    REPO = "REPO"
    RVPO = "RVPO"
    SLOA = "SLOA"
    SBSC = "SBSC"
    SCRP = "SCRP"
    SLEB = "SLEB"
    SHSL = "SHSL"
    SCIR = "SCIR"
    SCIE = "SCIE"
    SWPT = "SWPT"
    TBAS = "TBAS"
    TRBD = "TRBD"
    TRCP = "TRCP"


@dataclass(kw_only=True)
class GenericIdentification29:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification30:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )


class IndependentAmountConventionType1Code(Enum):
    NBTR = "NBTR"
    NATR = "NATR"
    SEGR = "SEGR"


class MarginCallResponse1Code(Enum):
    NVDA = "NVDA"
    RANT = "RANT"


@dataclass(kw_only=True)
class PostalAddress2:
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd_id: str = field(
        metadata={
            "name": "PstCdId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 16,
        }
    )
    twn_nm: str = field(
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


class RoundingMethod1Code(Enum):
    DRDW = "DRDW"
    DRUP = "DRUP"
    NONE = "NONE"
    CLSR = "CLSR"


@dataclass(kw_only=True)
class SupplementaryDataEnvelope1:
    any_element: None | object = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


class ThresholdType1Code(Enum):
    SECU = "SECU"
    UNSE = "UNSE"


@dataclass(kw_only=True)
class AgreementFramework1Choice:
    agrmt_frmwk: None | AgreementFramework1Code = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    prtry_id: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Amount1:
    agrd_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "AgrdAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    mrgn_call_req_id: str = field(
        metadata={
            "name": "MrgnCallReqId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    addtl_inf: None | str = field(
        default=None,
        metadata={
            "name": "AddtlInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 210,
        },
    )


@dataclass(kw_only=True)
class CollateralAccountIdentificationType1Choice:
    tp: None | CollateralAccountType1Code = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    prtry: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class IndependentAmount1:
    amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    cnvntn: IndependentAmountConventionType1Code = field(
        metadata={
            "name": "Cnvntn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class IndependentAmount2:
    desc: None | str = field(
        default=None,
        metadata={
            "name": "Desc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    cnvntn: IndependentAmountConventionType1Code = field(
        metadata={
            "name": "Cnvntn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class MarginCollateral1:
    held_by_pty_a: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "HeldByPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    held_by_pty_b: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "HeldByPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    prr_agrd_to_pty_a: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "PrrAgrdToPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    prr_agrd_to_pty_b: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "PrrAgrdToPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    in_trnst_to_pty_a: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "InTrnstToPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    in_trnst_to_pty_b: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "InTrnstToPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class NameAndAddress6:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        }
    )
    adr: PostalAddress2 = field(
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class ResponseType1Choice:
    cd: None | MarginCallResponse1Code = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    prtry: None | GenericIdentification30 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class SegregatedIndependentAmountMargin1:
    min_trf_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "MinTrfAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    rndg_amt: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "RndgAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    rndg_mtd: None | RoundingMethod1Code = field(
        default=None,
        metadata={
            "name": "RndgMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class SupplementaryData1:
    plc_and_nm: None | str = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: SupplementaryDataEnvelope1 = field(
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class VariationMargin1:
    thrshld_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "ThrshldAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    thrshld_tp: None | ThresholdType1Code = field(
        default=None,
        metadata={
            "name": "ThrshldTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    min_trf_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "MinTrfAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    rndg_amt: ActiveCurrencyAndAmount = field(
        metadata={
            "name": "RndgAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    rndg_mtd: RoundingMethod1Code = field(
        metadata={
            "name": "RndgMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class AggregatedIndependentAmount1:
    trad: None | IndependentAmount1 = field(
        default=None,
        metadata={
            "name": "Trad",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    val_at_rsk: None | IndependentAmount1 = field(
        default=None,
        metadata={
            "name": "ValAtRsk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    net_opn_pos: None | IndependentAmount1 = field(
        default=None,
        metadata={
            "name": "NetOpnPos",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    othr_amt: list[IndependentAmount2] = field(
        default_factory=list,
        metadata={
            "name": "OthrAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class AgreedAmount1:
    vartn_mrgn_amt: Amount1 = field(
        metadata={
            "name": "VartnMrgnAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    sgrtd_indpdnt_amt: None | Amount1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Agreement2:
    agrmt_dtls: str = field(
        metadata={
            "name": "AgrmtDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 140,
        }
    )
    agrmt_id: None | str = field(
        default=None,
        metadata={
            "name": "AgrmtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )
    agrmt_dt: XmlDate = field(
        metadata={
            "name": "AgrmtDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    base_ccy: str = field(
        metadata={
            "name": "BaseCcy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        }
    )
    agrmt_frmwk: None | AgreementFramework1Choice = field(
        default=None,
        metadata={
            "name": "AgrmtFrmwk",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Collateral1:
    vartn_mrgn: MarginCollateral1 = field(
        metadata={
            "name": "VartnMrgn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    sgrtd_indpdnt_amt: None | MarginCollateral1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralAccount1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    tp: None | CollateralAccountIdentificationType1Choice = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    nm: None | str = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass(kw_only=True)
class Margin1:
    vartn_mrgn: VariationMargin1 = field(
        metadata={
            "name": "VartnMrgn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    sgrtd_indpdnt_amt_mrgn: None | SegregatedIndependentAmountMargin1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmtMrgn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification33Choice:
    any_bic: None | str = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification29 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    nm_and_adr: None | NameAndAddress6 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Response1:
    rspn_tp_dtls: list[ResponseType1Choice] = field(
        default_factory=list,
        metadata={
            "name": "RspnTpDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_occurs": 1,
        },
    )
    desc: None | str = field(
        default=None,
        metadata={
            "name": "Desc",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "min_length": 1,
            "max_length": 140,
        },
    )


@dataclass(kw_only=True)
class AgreedAmount1Choice:
    agrd_amt_dtls: None | AgreedAmount1 = field(
        default=None,
        metadata={
            "name": "AgrdAmtDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    sgrtd_indpdnt_amt: None | Amount1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class CollateralBalance1Choice:
    ttl_coll: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "TtlColl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    coll_dtls: None | Collateral1 = field(
        default=None,
        metadata={
            "name": "CollDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    sgrtd_indpdnt_amt: None | MarginCollateral1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class MarginTerms1Choice:
    mrgn_dtls: None | Margin1 = field(
        default=None,
        metadata={
            "name": "MrgnDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    sgrtd_indpdnt_amt_mrgn: None | SegregatedIndependentAmountMargin1 = field(
        default=None,
        metadata={
            "name": "SgrtdIndpdntAmtMrgn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Obligation3:
    pty_a: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    svcg_pty_a: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    pty_b: PartyIdentification33Choice = field(
        metadata={
            "name": "PtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    svcg_pty_b: None | PartyIdentification33Choice = field(
        default=None,
        metadata={
            "name": "SvcgPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    coll_acct_id: None | CollateralAccount1 = field(
        default=None,
        metadata={
            "name": "CollAcctId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    xpsr_tp: None | ExposureType5Code = field(
        default=None,
        metadata={
            "name": "XpsrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    valtn_dt: DateAndDateTimeChoice = field(
        metadata={
            "name": "ValtnDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class MarginCall1:
    xpsd_amt_pty_a: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "XpsdAmtPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    xpsd_amt_pty_b: None | ActiveCurrencyAndAmount = field(
        default=None,
        metadata={
            "name": "XpsdAmtPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    xpsr_cnvntn: None | ExposureConventionType1Code = field(
        default=None,
        metadata={
            "name": "XpsrCnvntn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    indpdnt_amt_pty_a: None | AggregatedIndependentAmount1 = field(
        default=None,
        metadata={
            "name": "IndpdntAmtPtyA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    indpdnt_amt_pty_b: None | AggregatedIndependentAmount1 = field(
        default=None,
        metadata={
            "name": "IndpdntAmtPtyB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    mrgn_terms: None | MarginTerms1Choice = field(
        default=None,
        metadata={
            "name": "MrgnTerms",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    coll_bal: None | CollateralBalance1Choice = field(
        default=None,
        metadata={
            "name": "CollBal",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class MarginCallResponseV03:
    tx_id: str = field(
        metadata={
            "name": "TxId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    oblgtn: Obligation3 = field(
        metadata={
            "name": "Oblgtn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
            "required": True,
        }
    )
    agrmt: None | Agreement2 = field(
        default=None,
        metadata={
            "name": "Agrmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    mrgn_dtls_due_to_a: None | MarginCall1 = field(
        default=None,
        metadata={
            "name": "MrgnDtlsDueToA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    mrgn_dtls_due_to_b: None | MarginCall1 = field(
        default=None,
        metadata={
            "name": "MrgnDtlsDueToB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    agrd_amt_due_to_a: None | AgreedAmount1Choice = field(
        default=None,
        metadata={
            "name": "AgrdAmtDueToA",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    agrd_amt_due_to_b: None | AgreedAmount1Choice = field(
        default=None,
        metadata={
            "name": "AgrdAmtDueToB",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    rspn_dtls: None | Response1 = field(
        default=None,
        metadata={
            "name": "RspnDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )
    splmtry_data: list[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03",
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:colr.004.001.03"

    mrgn_call_rspn: MarginCallResponseV03 = field(
        metadata={
            "name": "MrgnCallRspn",
            "type": "Element",
            "required": True,
        }
    )



from __future__ import annotations

from dataclasses import dataclass, field
from enum import Enum

from xsdata.models.datatype import XmlDate, XmlDateTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01"


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


@dataclass(kw_only=True)
class GenericIdentification1:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    issr: None | str = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class GenericIdentification36:
    id: str = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    issr: str = field(
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    schme_nm: None | str = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class OriginalBusinessQuery1:
    msg_id: str = field(
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    msg_nm_id: None | str = field(
        default=None,
        metadata={
            "name": "MsgNmId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    cre_dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )


@dataclass(kw_only=True)
class SequenceRange1:
    fr_seq: str = field(
        metadata={
            "name": "FrSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    to_seq: str = field(
        metadata={
            "name": "ToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )


@dataclass(kw_only=True)
class SupplementaryDataEnvelope1:
    any_element: None | object = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass(kw_only=True)
class PostalAddress1:
    adr_tp: None | AddressType2Code = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    adr_line: list[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "max_occurs": 5,
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: None | str = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 70,
        },
    )
    bldg_nb: None | str = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_cd: None | str = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: None | str = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_sub_dvsn: None | str = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: str = field(
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        }
    )


@dataclass(kw_only=True)
class RequestType4Choice:
    pmt_ctrl: None | str = field(
        default=None,
        metadata={
            "name": "PmtCtrl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 4,
        },
    )
    enqry: None | str = field(
        default=None,
        metadata={
            "name": "Enqry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: None | GenericIdentification1 = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )


@dataclass(kw_only=True)
class SequenceRange1Choice:
    fr_seq: None | str = field(
        default=None,
        metadata={
            "name": "FrSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    to_seq: None | str = field(
        default=None,
        metadata={
            "name": "ToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    fr_to_seq: list[SequenceRange1] = field(
        default_factory=list,
        metadata={
            "name": "FrToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    eqseq: list[str] = field(
        default_factory=list,
        metadata={
            "name": "EQSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    neqseq: list[str] = field(
        default_factory=list,
        metadata={
            "name": "NEQSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class SupplementaryData1:
    plc_and_nm: None | str = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: SupplementaryDataEnvelope1 = field(
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class MessageHeader7:
    msg_id: str = field(
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        }
    )
    cre_dt_tm: None | XmlDateTime = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    req_tp: None | RequestType4Choice = field(
        default=None,
        metadata={
            "name": "ReqTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    orgnl_biz_qry: None | OriginalBusinessQuery1 = field(
        default=None,
        metadata={
            "name": "OrgnlBizQry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    qry_nm: None | str = field(
        default=None,
        metadata={
            "name": "QryNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass(kw_only=True)
class NameAndAddress5:
    nm: str = field(
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
            "min_length": 1,
            "max_length": 350,
        }
    )
    adr: None | PostalAddress1 = field(
        default=None,
        metadata={
            "name": "Adr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification120Choice:
    any_bic: None | str = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    prtry_id: None | GenericIdentification36 = field(
        default=None,
        metadata={
            "name": "PrtryId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    nm_and_adr: None | NameAndAddress5 = field(
        default=None,
        metadata={
            "name": "NmAndAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )


@dataclass(kw_only=True)
class PartyIdentification136:
    id: PartyIdentification120Choice = field(
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
        }
    )
    lei: None | str = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )


@dataclass(kw_only=True)
class ResendSearchCriteria2:
    biz_dt: None | XmlDate = field(
        default=None,
        metadata={
            "name": "BizDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    seq_nb: None | str = field(
        default=None,
        metadata={
            "name": "SeqNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    seq_rg: None | SequenceRange1Choice = field(
        default=None,
        metadata={
            "name": "SeqRg",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )
    orgnl_msg_nm_id: None | str = field(
        default=None,
        metadata={
            "name": "OrgnlMsgNmId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    file_ref: None | str = field(
        default=None,
        metadata={
            "name": "FileRef",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_length": 1,
            "max_length": 35,
        },
    )
    rcpt: PartyIdentification136 = field(
        metadata={
            "name": "Rcpt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
        }
    )


@dataclass(kw_only=True)
class ResendRequestV01:
    msg_hdr: MessageHeader7 = field(
        metadata={
            "name": "MsgHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "required": True,
        }
    )
    rsnd_sch_crit: list[ResendSearchCriteria2] = field(
        default_factory=list,
        metadata={
            "name": "RsndSchCrit",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
            "min_occurs": 1,
        },
    )
    splmtry_data: list[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01",
        },
    )


@dataclass(kw_only=True)
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:admi.006.001.01"

    rsnd_req: ResendRequestV01 = field(
        metadata={
            "name": "RsndReq",
            "type": "Element",
            "required": True,
        }
    )



from pyiso20022.colr.colr_005_001_06.colr_005_001_06 import (
    ActiveOrHistoricCurrencyAndAmount,
    BlockChainAddressWallet5,
    ClosingDate4Choice,
    CollateralAccount3,
    CollateralAccountIdentificationType3Choice,
    CollateralAccountType1Code,
    CollateralCancellationReason1,
    CollateralCancellationType1Choice,
    CollateralManagementCancellationReason1Code,
    CollateralManagementCancellationRequestV06,
    CollateralRole1Code,
    CollateralTransactionType1Choice,
    CollateralTransactionType1Code,
    Date3Choice,
    DateAndDateTime2Choice,
    DateType2Code,
    Document,
    ExposureType11Code,
    ExposureType21Choice,
    GenericIdentification30,
    GenericIdentification36,
    NameAndAddress6,
    Obligation8,
    PartyIdentification178Choice,
    PostalAddress2,
    Reference3Choice,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "ActiveOrHistoricCurrencyAndAmount",
    "BlockChainAddressWallet5",
    "ClosingDate4Choice",
    "CollateralAccount3",
    "CollateralAccountIdentificationType3Choice",
    "CollateralAccountType1Code",
    "CollateralCancellationReason1",
    "CollateralCancellationType1Choice",
    "CollateralManagementCancellationReason1Code",
    "CollateralManagementCancellationRequestV06",
    "CollateralRole1Code",
    "CollateralTransactionType1Choice",
    "CollateralTransactionType1Code",
    "Date3Choice",
    "DateAndDateTime2Choice",
    "DateType2Code",
    "Document",
    "ExposureType11Code",
    "ExposureType21Choice",
    "GenericIdentification30",
    "GenericIdentification36",
    "NameAndAddress6",
    "Obligation8",
    "PartyIdentification178Choice",
    "PostalAddress2",
    "Reference3Choice",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.head.head_001_001_01.head_001_001_01 import (
    AddressType2Code,
    AppHdr,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    BusinessApplicationHeader1,
    BusinessApplicationHeaderV01,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    ContactDetails2,
    CopyDuplicate1Code,
    DateAndPlaceOfBirth,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification8,
    GenericFinancialIdentification1,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    NamePrefix1Code,
    OrganisationIdentification7,
    OrganisationIdentificationSchemeName1Choice,
    Party9Choice,
    Party10Choice,
    PartyIdentification42,
    PersonIdentification5,
    PersonIdentificationSchemeName1Choice,
    PostalAddress6,
    SignatureEnvelope,
)

__all__ = [
    "AddressType2Code",
    "AppHdr",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "BusinessApplicationHeader1",
    "BusinessApplicationHeaderV01",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "ContactDetails2",
    "CopyDuplicate1Code",
    "DateAndPlaceOfBirth",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification8",
    "GenericFinancialIdentification1",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "NamePrefix1Code",
    "OrganisationIdentification7",
    "OrganisationIdentificationSchemeName1Choice",
    "Party10Choice",
    "Party9Choice",
    "PartyIdentification42",
    "PersonIdentification5",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress6",
    "SignatureEnvelope",
]
